package cli

import (
	"os"
	"testing"

	"github.com/danielmiessler/fabric/internal/i18n"

	"github.com/stretchr/testify/assert"
)

func TestCli(t *testing.T) {
	t.Skip("Skipping test for now, collision with flag -t")
	originalArgs := os.Args
	defer func() { os.Args = originalArgs }()

	os.Args = []string{os.Args[0]}
	err := Cli("test")
	assert.Error(t, err)
	assert.Equal(t, i18n.T("chatter_error_no_session_pattern_user_messages"), err.Error())
}
